==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ru.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Документы",
    "Can't create document" : "Невозможно создать документ",
    "You don't have permission to rename this document" : "У вас нет прав для переименования этого документа.",
    "Directory saved successfully." : "Каталог успешно сохранён.",
    "An error occurred while changing directory." : "При смене каталога произошла ошибка.",
    "Saved" : "Сохранено",
    "Format filter server is down or misconfigured" : "Сервер фильтрации формата не работает или настроен неправильно",
    "Conversion failed. Check log for details." : "Конвертация не удалась. За деталями обратитесь к журналу.",
    "document-styles" : "стили-документа",
    "document-content" : "содержимое-документа",
    "bold" : "жирный",
    "italic" : "курсив",
    "solid" : "сплошной",
    "pt" : "pt",
    "Saving..." : "Сохранение...",
    "Failed to load documents." : "Не удалось загрузить документы.",
    "No documents were found. Upload or create a document to get started!" : "Документы не найдены. Чтобы начать, загрузите или создайте документ!",
    "No connection to server. Trying to reconnect." : "Нет связи с сервером. Попытка переподключения.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Если вы покинете эту страницу в режиме Редактора, то некоторые данные могут не сохраниться. Рекомендуется вместо этого использовать кнопку 'Закрыть'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Не удалось открыть документ. Убедитесь что файл можно открыть с помощью внешнего odt-редактора. Также ошибка может означать, что файл был удален или к нему закрыли доступ.",
    "Save" : "Сохранить",
    "Loading documents..." : "Загрузка документов...",
    "'.' is an invalid file name." : "'.' - неправильное имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Неправильное имя, символы '\\', '/', '<', '>', ':', '\"', '|', '?' и '*' недопустимы.",
    "Align Left" : "Выровнять по левому краю",
    "Alignment" : "Выравнивание",
    "Align Right" : "Выровнять по правому краю",
    "Annotate" : "Аннотация",
    "Background" : "Фон",
    "Bold" : "Жирный",
    "Bottom" : "Снизу",
    "Cancel" : "Отмена",
    "Center" : "По центру",
    "Clone" : "Клонировать",
    "Clone this Style" : "Клонировать этот стиль",
    "Close" : "Закрыть",
    "Color" : "Цвет",
    "Create" : "Создать",
    "Decrease Indent" : "Уменьшить отступ",
    "Default Style" : "Стиль по умолчанию",
    "Delete" : "Удалить",
    "Family" : "Семья",
    "Font" : "Шрифт",
    "Font Effects" : "Шрифтовые эффекты",
    "Format" : "Формат",
    "Increase Indent" : "Увеличить отступ",
    "Insert Image" : "Вставить изображение",
    "Invite Members" : "Пригласить участников",
    "Italic" : "Курсив",
    "Justified" : "По ширине",
    "Justify" : "Выровнять по ширине",
    "Left" : "Слева",
    "Loading" : "Загрузка",
    "Members" : "Участники",
    "New Name:" : "Новое имя:",
    "OK" : "ОК",
    "Open" : "Открыть",
    "Options" : "Опции",
    "Paragraph..." : "Абзац...",
    "Paragraph Styles" : "Стили абзацев",
    "Redo" : "Повторить",
    "Right" : "Справа",
    "Size" : "Размер",
    "Spacing" : "Расстояние между строк",
    "Strikethrough" : "Перечёркнутый",
    "Style" : "Стиль",
    "Text" : "Текст",
    "Top" : "По верху",
    "Underline" : "Подчеркнутый",
    "Undo" : "Отмена",
    "Unknown Author" : "Неизвестный автор",
    "Edit" : "Редактировать",
    "Share" : "Открыть доступ",
    "guest" : "Гость",
    "MS Word support (requires openOffice/libreOffice)" : "Поддержка MS Word (требуется openOffice/libreOffice)",
    "Local" : "Локальная",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice установлен на этом сервере. Путь до бинарных файлов настраивается в переменной preview_libreoffice_path в файле config.php",
    "External" : "Внешний сервер",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice установлен на внешнем сервере выполняющем форматирование и фильтрацию",
    "Disabled" : "Отключена",
    "No MS Word support" : "Поддержка MS Word отсутствует",
    "scheme://domain.tld[:port]" : "протокол://домен.зона[:порт]",
    "Server URL" : "URL сервера",
    "Apply and test" : "Применить и проверить",
    "New document" : "Новый документ",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "Upload" : "Загрузка",
    "Save new documents to" : "Сохранять новые документы в",
    "Wrong password. Please retry." : "Неправильный пароль. Повторите попытку.",
    "Password" : "Пароль",
    "Guest %s" : "Гость %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Срок действия ссылки истек, либо ссылка никогда не существовала. Пожалуйста, обратитесь к человеку, который поделился ею, за подробностями.",
    "Advanced feature-set" : "Расширенные функции",
    "(Unstable)" : "(Нестабильно)"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ru.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Документы",
    "Can't create document" : "Невозможно создать документ",
    "You don't have permission to rename this document" : "У вас нет прав для переименования этого документа.",
    "File does not exist" : "Файл не существует",
    "Directory saved successfully." : "Каталог успешно сохранён.",
    "An error occurred while changing directory." : "При смене каталога произошла ошибка.",
    "Saved" : "Сохранено",
    "Format filter server is down or misconfigured" : "Сервер фильтрации формата не работает или настроен неправильно",
    "Conversion failed. Check log for details." : "Конвертация не удалась. За деталями обратитесь к журналу.",
    "Saving..." : "Сохранение...",
    "Failed to load documents." : "Не удалось загрузить документы.",
    "No documents were found. Upload or create a document to get started!" : "Документы не найдены. Чтобы начать, загрузите или создайте документ!",
    "No connection to server. Trying to reconnect." : "Нет связи с сервером. Попытка переподключения.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Если вы покинете эту страницу в режиме Редактора, то некоторые данные могут не сохраниться. Рекомендуется вместо этого использовать кнопку 'Закрыть'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Не удалось открыть документ. Убедитесь что файл можно открыть с помощью внешнего odt-редактора. Также ошибка может означать, что файл был удален или к нему закрыли доступ.",
    "Save" : "Сохранить",
    "Loading documents..." : "Загрузка документов...",
    "'.' is an invalid file name." : "'.' - неправильное имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Неправильное имя, символы '\\', '/', '<', '>', ':', '\"', '|', '?' и '*' недопустимы.",
    "Align Left" : "Выровнять по левому краю",
    "Alignment" : "Выравнивание",
    "Align Right" : "Выровнять по правому краю",
    "Annotate" : "Аннотация",
    "Background" : "Фон",
    "Bold" : "Жирный",
    "Bottom" : "Снизу",
    "Cancel" : "Отмена",
    "Center" : "По центру",
    "Clone" : "Клонировать",
    "Clone this Style" : "Клонировать этот стиль",
    "Close" : "Закрыть",
    "Color" : "Цвет",
    "Create" : "Создать",
    "Decrease Indent" : "Уменьшить отступ",
    "Default Style" : "Стиль по умолчанию",
    "Delete" : "Удалить",
    "Family" : "Семья",
    "Font" : "Шрифт",
    "Font Effects" : "Шрифтовые эффекты",
    "Format" : "Формат",
    "Increase Indent" : "Увеличить отступ",
    "Insert Image" : "Вставить изображение",
    "Invite Members" : "Пригласить участников",
    "Italic" : "Курсив",
    "Justified" : "По ширине",
    "Justify" : "Выровнять по ширине",
    "Left" : "Слева",
    "Loading" : "Загрузка",
    "Members" : "Участники",
    "New Name:" : "Новое имя:",
    "OK" : "ОК",
    "Open" : "Открыть",
    "Options" : "Опции",
    "Paragraph..." : "Абзац...",
    "Paragraph Styles" : "Стили абзацев",
    "Redo" : "Повторить",
    "Right" : "Справа",
    "Size" : "Размер",
    "Spacing" : "Расстояние между строк",
    "Strikethrough" : "Перечёркнутый",
    "Style" : "Стиль",
    "Text" : "Текст",
    "Top" : "По верху",
    "Underline" : "Подчеркнутый",
    "Undo" : "Отмена",
    "Unknown Author" : "Неизвестный автор",
    "Shared" : "Общий доступ",
    "Error" : "Ошибка",
    "Error while sharing" : "При попытке поделиться произошла ошибка",
    "Error while unsharing" : "При закрытии доступа произошла ошибка",
    "Error while changing permissions" : "При изменении прав доступа произошла ошибка",
    "Shared with you and the group {group} by {owner}" : "{owner} поделился с вами и группой {group} ",
    "Shared with you by {owner}" : "С вами поделился {owner} ",
    "Share with users or groups …" : "Поделиться с пользователями или группами ...",
    "Share with users, groups or remote users …" : "Поделиться с пользователями, группами или удаленными пользователями ...",
    "Share" : "Открыть доступ",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделиться с людьми на других серверах ownCloud используя синтакс username@example.com/owncloud",
    "Share link" : "Поделиться ссылкой",
    "The public link will expire no later than {days} days after it is created" : "Срок действия публичной ссылки истекает не позже чем через {days} дней после её создания",
    "Link" : "Ссылка",
    "Password protect" : "Защитить паролем",
    "Password" : "Пароль",
    "Choose a password for the public link" : "Укажите пароль для публичной ссылки",
    "Allow editing" : "Разрешить редактирование",
    "Email link to person" : "Отправить ссылку по электронной почте",
    "Send" : "Отправить",
    "Set expiration date" : "Установить срок действия",
    "Expiration" : "Срок действия",
    "Expiration date" : "Дата окончания",
    "An error occured. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
    "Adding user..." : "Добавляем пользователя...",
    "group" : "группа",
    "remote" : "удаленный",
    "Resharing is not allowed" : "Повторное открытие доступа запрещено",
    "Shared in {item} with {user}" : "Общий доступ в {item} для {user}",
    "Unshare" : "Закрыть доступ",
    "notify by email" : "уведомить по почте",
    "can share" : "можно поделиться",
    "can edit" : "можно редактировать",
    "access control" : "контроль доступа",
    "create" : "создать",
    "change" : "изменить",
    "delete" : "удалить",
    "Password protected" : "Защищено паролем",
    "Error unsetting expiration date" : "Ошибка при отмене срока доступа",
    "Error setting expiration date" : "Ошибка при установке срока доступа",
    "Sending ..." : "Отправляется ...",
    "Email sent" : "Письмо отправлено",
    "Warning" : "Предупреждение",
    "Edit" : "Редактировать",
    "guest" : "Гость",
    "MS Word support (requires openOffice/libreOffice)" : "Поддержка MS Word (требуется openOffice/libreOffice)",
    "Local" : "Локальная",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice установлен на этом сервере. Путь до бинарных файлов настраивается в переменной preview_libreoffice_path в файле config.php",
    "External" : "Внешний сервер",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice установлен на внешнем сервере выполняющем форматирование и фильтрацию",
    "Disabled" : "Отключена",
    "No MS Word support" : "Поддержка MS Word отсутствует",
    "scheme://domain.tld[:port]" : "протокол://домен.зона[:порт]",
    "Server URL" : "URL сервера",
    "Apply and test" : "Применить и проверить",
    "New document" : "Новый документ",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "Upload" : "Загрузка",
    "Save new documents to" : "Сохранять новые документы в",
    "Wrong password. Please retry." : "Неправильный пароль. Повторите попытку.",
    "Guest %s" : "Гость %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Срок действия ссылки истек, либо ссылка никогда не существовала. Пожалуйста, обратитесь к человеку, который поделился ею, за подробностями.",
    "Advanced feature-set" : "Расширенные функции",
    "(Unstable)" : "(Нестабильно)"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
